| Title: | Handle R Requests from R Service Bus Applications with JSON Payloads |
|---|---|
| Description: | Package to Handle R Requests from R Service Bus Applications with JSON Payloads in a generic way. The incoming request is encoded as a string (character vector of length one) containing the JSON file passed through by the client. |
| Authors: | Tobias Verbeke |
| Maintainer: | Tobias Verbeke <[email protected]> |
| License: | GPL-3 |
| Version: | 1.1.2 |
| Built: | 2026-06-09 08:15:31 UTC |
| Source: | https://github.com/cran/RSBJson |
Generate All Possible Combinations of m Out of n
allPossibleCombinations(n, m)allPossibleCombinations(n, m)
n |
n |
m |
m |
a JSON string with all possible combinations;
object of class json as returned by toJSON
allPossibleCombinations(4, 2)allPossibleCombinations(4, 2)
The function extracts relevant information from the JSON string to dispatch to the appropriate R wrapper for that particular application
RSBJsonService(jsonString)RSBJsonService(jsonString)
jsonString |
character vector of length one containing the JSON string |
object of class json as returned by toJSON
examplePath <- system.file("examples", "example.json", package = "RSBJson") exampleCon <- file(description = examplePath, open = "rt") exampleLines <- readLines(exampleCon) close(exampleCon) exampleString <- paste(exampleLines, collapse = "\n") (string <- RSBJsonService(jsonString = exampleString))examplePath <- system.file("examples", "example.json", package = "RSBJson") exampleCon <- file(description = examplePath, open = "rt") exampleLines <- readLines(exampleCon) close(exampleCon) exampleString <- paste(exampleLines, collapse = "\n") (string <- RSBJsonService(jsonString = exampleString))